# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We don't really need ExtUtils::MakeMaker ≥ 6.30
%global old_eumm %(perl -MExtUtils::MakeMaker -e 'print (($ExtUtils::MakeMaker::VERSION < 6.30) ? 1 : 0);' 2>/dev/null || echo 0)

# We need a recent version of Test::More
%global quite_old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION) < 0.96 ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Class-Tiny
Version:	0.014
Release:	1.%{__distinit}%{__distvers}
Summary:	Minimalist class construction
License:	ASL 2.0
Group:		Development/Libraries
URL:		https://metacpan.org/release/Class-Tiny
Source0:	http://cpan.metacpan.org/authors/id/D/DA/DAGOLDEN/Class-Tiny-%{version}.tar.gz
Source1:	T-M-0.96.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Build
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.17
# Module
BuildRequires:	perl(Carp)
# Test suite
BuildRequires:	perl(base)
BuildRequires:	perl(CPAN::Meta)
BuildRequires:	perl(CPAN::Meta::Requirements)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(lib)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(subs)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(warnings)
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Compatibility with old Perls
%if %(perl -e 'print $] < 5.010 ? 1 : 0;')
BuildRequires:	perl(MRO::Compat)
Requires:	perl(MRO::Compat)
%else
BuildRequires:	perl(mro)
Requires:	perl(mro)
%endif
%if %(perl -e 'print $] < 5.014 ? 1 : 0;')
BuildRequires:	perl(Devel::GlobalDestruction)
%else
%global __requires_exclude ^perl\\(Devel::GlobalDestruction\\)
%endif

%description
This module offers a minimalist class construction kit in around 120 lines of
code. Here is a list of features:

 * Defines attributes via import arguments
 * Generates read-write accessors
 * Supports lazy attribute defaults
 * Supports custom accessors
 * Superclass provides a standard new constructor
 * new takes a hash reference or list of key/value pairs
 * new has heuristics to catch constructor attribute typos
 * new calls BUILD for each class from parent to child
 * Superclass provides a DESTROY method
 * DESTROY calls DEMOLISH for each class from child to parent

It uses no non-core modules for any recent Perl. On Perls older than v5.10 it
requires MRO::Compat. On Perls older than v5.14, it
requires Devel::GlobalDestruction.

%prep
%setup -q -n Class-Tiny-%{version}

# Use of subtests requires Test::More ≥ 0.96; use a bundled version if we don't have it
%if %{quite_old_test_more}
tar xfz %{SOURCE1}
find inc -type f >> MANIFEST
%endif

%build
# Use our local Test::More if necessary
[ -d inc/ ] && export PERL5LIB=$(pwd)/inc

perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
%{_fixperms} %{buildroot}

%check
# Use our local Test::More if necessary
[ -d inc/ ] && export PERL5LIB=$(pwd)/inc

make test

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc CONTRIBUTING Changes LICENSE README
%{perl_vendorlib}/Class/
%{_mandir}/man3/Class::Tiny.3pm*

%changelog
* Thu Nov 28 2013 Paul Howarth <paul@city-fan.org> - 0.014-1
- Update to 0.014
  - Put back a 'no warnings "once"' line that caused downstream warnings

* Tue Nov 26 2013 Paul Howarth <paul@city-fan.org> - 0.013-1
- Update to 0.013
  - Expanded comparision to Object::Tiny and Class::Accessor

* Fri Nov  1 2013 Paul Howarth <paul@city-fan.org> - 0.012-1
- Update to 0.012
  - Added documentation notes about multiple inheritance and attribute defaults
    under subclassing
  - Added tests for multiple inheritance

* Thu Sep 26 2013 Paul Howarth <paul@city-fan.org> - 0.011-1
- Update to 0.011
  - Compile test could hang on Windows
  - ExtUtils::MakeMaker configure_requires dropped to 6.17
- Drop redundant patch for building with ExtUtils::MakeMaker < 6.30

* Wed Sep 18 2013 Paul Howarth <paul@city-fan.org> - 0.010-1
- Update to 0.010
  - Suppressed 'used only once' warnings
    (https://github.com/dagolden/Class-Tiny/issues/9)

* Tue Sep 17 2013 Paul Howarth <paul@city-fan.org> - 0.009-1
- Update to 0.009
  - Fix "won't stay shared" bug on older perls
    (https://github.com/dagolden/Class-Tiny/issues/8)
- BR:/R: perl(mro) for Perl ≥ 5.10
- Use local Test::More in %%build too, so Makefile.PL doesn't complain

* Sun Sep 15 2013 Paul Howarth <paul@city-fan.org> - 0.008-1
- Initial RPM version
